# rndpwr.s - random number generator based on 16 byte seed
#   	generates a random number with normal distribution
#   	from 0 to (2^n) - 1
#   	where 1 <= n <= 32
# Version 1.3.0
# Copyright (C) 2000-2010   dondalah721@yahoo.com (Dondalah)

# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License as
# published by the Free Software Foundation; either version 2 of
# the License, or (at your option) any later version.

# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.

# You should have received a copy of the GNU General Public License
# along with this program; if not, write to:

#	Free Software Foundation, Inc.
#	59 Temple Place - Suite 330
#	Boston, MA  02111-1307, USA.

# Usage:
#   	unsigned int rndpwr(int bits,
#		unsigned char *sd);

# called by:
#   	unsigned int rndnum(unsigned int limit,
#		unsigned char *sd);

# subroutine calls: 
#   	void rnd(unsigned char *sd);

# initialize the seed with:
#   	unsigned char *sd;
#   	sd = (unsigned char *) initrnd();

	.file	"rndpwr.s"
	.version	"1.3.0"
gcc2_compiled.:
.text
	.align 4
.globl rndpwr
	.type	 rndpwr,@function
rndpwr:
	pushl %ebp
	movl %esp,%ebp
	pushl %ebx
	pushl %ecx
	pushl %esi
	xorl %ebx,%ebx		/* clear result */
	movl 8(%ebp),%ecx	/* loop counter = #bits */
	movl 12(%ebp),%esi	/* pointer to seed */
	cmpl $32,%ecx		/* if parm1 > 32 */
	ja   fail		/* default = 0 */
	orl  %ecx,%ecx		/* if parm1 <> 0 */
	jnz  again		/* calculate result */
fail:
	xorl %eax,%eax		/* default = 0 */
	jmp  .L1		/* return */
again:
	pushl %esi		/* seed parm */
	/* next iteration of randomizer */
	call rnd		/* rnd(sd); */
	addl $4,%esp		/* restore stack */
	mov  15(%esi),%al	/* high order byte of seed */
	shr  $7,%al		/* high order bit of seed */
	shll $1,%ebx		/* rslt *= 2; */
	or   %al,%bl		/* rslt |= bit; */
	loop again
	movl %ebx,%eax		/* return(rslt) */

	jmp .L1
	.align 4
.L1:
	popl %esi
	popl %ecx
	popl %ebx
	movl %ebp,%esp
	popl %ebp
	ret
.Lfe1:
	.size	 rndpwr,.Lfe1-rndpwr
	.ident	"GCC: (GNU) 2.7.2"
